@@ -55,6 +55,11 @@ class GetTokenTest(APIRequestTestCase):
         with self.assertRaises(Token.DoesNotExist):
             Token.objects.get(pk=token.pk)
 
+    def test_delete_no_token(self):
+        request = self.create_request('delete')
+        response = self.view_class.as_view()(request)
+        self.assertEqual(response.status_code, status.HTTP_204_NO_CONTENT)
+
 
 class TestRegisterView(APIRequestTestCase):
     view_class = views.UserRegister
@@ -280,6 +285,18 @@ class TestPasswordReset(APIRequestTestCase):
         response = view(request, uidb64=uid, token=token)
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
+    def test_full_stack_wrong_url(self):
+        user = UserFactory.create()
+        token = default_token_generator.make_token(user)
+        uid = urlsafe_base64_encode(b'0')  # Invalid uid, therefore bad url
+
+        view_name = 'user_management_api:password_reset_confirm'
+        url = reverse(view_name, kwargs={'uidb64': uid, 'token': token})
+        response = self.client.put(url)
+        self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
+
+        self.assertTrue(hasattr(response, 'accepted_renderer'))
+
 
 class TestPasswordChange(APIRequestTestCase):
     view_class = views.PasswordChange
@@ -465,6 +482,18 @@ class TestVerifyAccountView(APIRequestTestCase):
         logged_in_user = User.objects.get(pk=other_user.pk)
         self.assertTrue(logged_in_user.email_verification_required)
 
+    def test_full_stack_wrong_url(self):
+        user = UserFactory.create()
+        token = default_token_generator.make_token(user)
+        uid = urlsafe_base64_encode(b'0')  # Invalid uid, therefore bad url
+
+        view_name = 'user_management_api:verify_user'
+        url = reverse(view_name, kwargs={'uidb64': uid, 'token': token})
+        response = self.client.post(url)
+        self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
+
+        self.assertTrue(hasattr(response, 'accepted_renderer'))
+
 
 class TestProfileDetail(APIRequestTestCase):
     view_class = views.ProfileDetail
